@@ -1,8 +1,9 @@
 package URI::Fast;
-# ABSTRACT: A fast(er) URI parser
-$URI::Fast::XS_VERSION = $URI::Fast::VERSION = '0.35_4'; # TRIAL
 
-$URI::Fast::VERSION = '0.354';use utf8;
+our $XS_VERSION = our $VERSION = '0.35_5';
+$VERSION =~ tr/_//;
+
+use utf8;
 use strict;
 use warnings;
 no strict 'refs';
@@ -11,7 +12,7 @@ use Carp;
 use Exporter;
 
 require XSLoader;
-XSLoader::load('URI::Fast', $URI::Fast::XS_VERSION);
+XSLoader::load('URI::Fast', $XS_VERSION);
 
 use Exporter 'import';
 
@@ -187,23 +188,12 @@ sub compare {
   return 1;
 }
 
-
-1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
+=encoding UTF8
 
 =head1 NAME
 
 URI::Fast - A fast(er) URI parser
 
-=head1 VERSION
-
-version 0.35_4
-
 =head1 SYNOPSIS
 
   use URI::Fast qw(uri);
@@ -565,9 +555,10 @@ Jeff Ober <sysread@fastmail.fm>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Jeff Ober.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This software is copyright (c) 2018 by Jeff Ober. This is free software; you
+can redistribute it and/or modify it under the same terms as the Perl 5
+programming language system itself.
 
 =cut
+
+1;
